@@ -1,4 +1,4 @@
 from redis import RedisDict
 from memory import MemoryDict
-from models import Durabledict
+from models import ModelDict
 from zookeeper import ZookeeperDict
\ No newline at end of file
